pub struct CodeScanner;Expand description
Code violation scanner.
Detects command injection, data exfiltration, privilege escalation, supply chain attacks, obfuscation, filesystem abuse, and crypto misuse in sandbox output using fast substring matching.
Implementations
Sourceimpl CodeScanner
impl CodeScanner